clear
clc
%% import Hertz pressure

process_image=imread('Hertz_pressure.tiff');
process_image=double(process_image);

%% find contact center and calculate radius


pixel_length = 0.129 %in um

[r c] = find(process_image>0);
center_coordinate = [mean(r) mean(c)];

%get the radius

rad=max(((r-center_coordinate(1)).^2+(c-center_coordinate(2)).^2).^0.5);
rad=rad.*pixel_length;
%%get normal force

N_force=sum(process_image(:).*(0.129*10^-6)^2);


%% input CoF
Cof=0.48
Exp_N=0.04587./Cof
corr_f=Exp_N./N_force;
%% input exp friction force
Exp_f=[0.03645,0.03922,0.04216,0.04393,0.04587];
fr=Exp_f./corr_f;
%%
%calculate use N_force and fr and Cof;

slip_r=rad*(1-fr./(Cof*N_force)).^(1/3);
a=[1:floor(rad)];
m=1;
for i=1:length(slip_r)
    slip_a=length(a)-length(find(a>=slip_r(i)));
    taup_ratio(m,1:length(a))=Cof;
    
    taup_ratio(m,1:slip_a)=taup_ratio(m,1:slip_a)-Cof.*(slip_r(i)./rad).*(1-(a(1:slip_a)./slip_r(i)).^2).^0.5./(1-(a(1:slip_a)./rad).^2).^0.5;
    m=m+1;
end

figure('OuterPosition',[0 0 800 800]);
axes1 = axes('Position',...
    [0.240150004321337 0.16948216331497 0.70 0.77]);
hold(axes1,'on')
xlabel('a (\mum)');

% Create xlabel
ylabel('$\frac{\tau}{P}$ (a.u.)','Interpreter','Latex');
%ylabel('\Delta\tau (MPa)');
box(axes1,'on');

for i=1:length(fr)
    plot(a-1,taup_ratio(i,:));
end

legend('24s','25.5s','27.5s','29s','32s');
xlim([0,26])
ylim([0.2,1])
%% distance plot
    R = NaN(size(process_image(:,:,1)));
    for i =1:size(process_image(:,:,1),1)
        for j=1:size(process_image(:,:,1),2)
            R(i,j) = sqrt((i-center_coordinate(1))^2+(j-center_coordinate(2))^2);     
        end   
    end
    R=R.*pixel_length;
%% ratio_map
for i=1:length(slip_r)
temp_Ratio_map=zeros(size(process_image(:,:,1)));
temp_Ratio_map(find(R<=rad))=Cof;
slip_zone=find(R<=slip_r(i));
temp_Ratio_map(slip_zone)=temp_Ratio_map(slip_zone)-Cof.*(slip_r(i)./rad).*(1-(R(slip_zone)./slip_r(i)).^2).^0.5./(1-(R(slip_zone)./rad).^2).^0.5;
if i==1
Mindlin_map=temp_Ratio_map;
else
Mindlin_map=cat(3 , Mindlin_map, temp_Ratio_map);
end
end 


%% 4D plot

[X,Y]=meshgrid(1:750,1:750);
X=X.*0.129;
Y=Y.*0.129;
time=[24,25.5,27.5,29,32];
figure('OuterPosition',[0 0 1200 1000]);
for i=1:length(slip_r)
    Z=time(i).*ones(size(X));
    C=Mindlin_map(:,:,i);
    C(find(C==0))=NaN;
    surf(X,Y,Z,C,'EdgeColor','None','FaceAlpha',0.45);
    hold on
end
box on
view(-40,40)
xlim([15,85]);
ylim([15,85]);
zlim([23.5,33]);
caxis([0 0.5])


xlabel('X (\mum)');
ylabel('Y (\mum)');
zlabel('Time (s)');

a=colorbar;
ylabel(a,'\tau /P');